@@ -1,5 +1,5 @@
 package CPAN::Perl::Releases;
-$CPAN::Perl::Releases::VERSION = '2.54';
+$CPAN::Perl::Releases::VERSION = '2.60';
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
 
 use strict;
@@ -35,7 +35,6 @@ our $data =
 "5.6.1" => { id => 'GSAR' },
 "5.6.2" => { id => 'RGARCIA' },
 "5.7.0" => { id => 'JHI' },
-"5.7.1" => { id => 'JHI' },
 "5.7.2" => { id => 'JHI' },
 "5.7.3" => { id => 'JHI' },
 "5.8.0" => { id => 'JHI' },
@@ -114,14 +113,7 @@ our $data =
 "5.17.9" => { id => 'BINGOS' },
 "5.17.10" => { id => 'CORION' },
 "5.17.11" => { id => 'RJBS' },
-"5.18.0-RC1" => { id => 'RJBS' },
-"5.18.0-RC2" => { id => 'RJBS' },
-"5.18.0-RC3" => { id => 'RJBS' },
-"5.18.0-RC4" => { id => 'RJBS' },
 "5.18.0" => { id => 'RJBS' },
-"5.18.1-RC1" => { id => 'RJBS' },
-"5.18.1-RC2" => { id => 'RJBS' },
-"5.18.1-RC3" => { id => 'RJBS' },
 "5.18.1" => { id => 'RJBS' },
 "5.19.0" => { id => 'RJBS' },
 "5.19.1" => { id => 'DAGOLDEN' },
@@ -130,17 +122,12 @@ our $data =
 "5.19.4" => { id => 'SHAY' },
 "5.19.5" => { id => 'SHAY' },
 "5.19.6" => { id => 'BINGOS' },
-"5.18.2-RC1" => { id => 'RJBS' },
-"5.18.2-RC2" => { id => 'RJBS' },
-"5.18.2-RC3" => { id => 'RJBS' },
 "5.19.7" => { id => 'ABIGAIL' },
-"5.18.2-RC4" => { id => 'RJBS' },
 "5.18.2" => { id => 'RJBS' },
 "5.19.8" => { id => 'RJBS' },
 "5.19.9" => { id => 'TONYC' },
 "5.19.10" => { id => 'ARC' },
 "5.19.11" => { id => 'SHAY' },
-"5.20.0-RC1" => { id => 'RJBS' },
 "5.20.0" => { id => 'RJBS' },
 "5.21.0" => { id => 'RJBS' },
 "5.21.1" => { id => 'WOLFSAGE' },
@@ -149,9 +136,7 @@ our $data =
 "5.20.1-RC1" => { id => 'SHAY' },
 "5.20.1-RC2" => { id => 'SHAY' },
 "5.20.1" => { id => 'SHAY' },
-"5.18.3-RC1" => { id => 'RJBS' },
 "5.21.4" => { id => 'SHAY' },
-"5.18.3-RC2" => { id => 'RJBS' },
 "5.18.3" => { id => 'RJBS' },
 "5.18.4" => { id => 'RJBS' },
 "5.21.5" => { id => 'ABIGAIL' },
@@ -163,8 +148,6 @@ our $data =
 "5.21.9" => { id => 'XSAWYERX' },
 "5.21.10" => { id => 'SHAY' },
 "5.21.11" => { id => 'SHAY' },
-"5.22.0-RC1" => { id => 'RJBS' },
-"5.22.0-RC2" => { id => 'RJBS' },
 "5.22.0" => { id => 'RJBS' },
 "5.23.0" => { id => 'RJBS' },
 "5.23.1" => { id => 'WOLFSAGE' },
@@ -181,6 +164,9 @@ our $data =
 "5.22.1-RC4" => { id => 'SHAY' },
 "5.22.1" => { id => 'SHAY' },
 "5.23.6" => { id => 'DAGOLDEN' },
+"5.23.7" => { id => 'STEVAN' },
+"5.23.8" => { id => 'XSAWYERX' },
+"5.23.9" => { id => 'ABIGAIL' },
 };
 
 sub perl_tarballs {
@@ -248,7 +234,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 2.54
+version 2.60
 
 =head1 SYNOPSIS
 
@@ -315,7 +301,7 @@ Chris Williams <chris@bingosnet.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Chris Williams.
+This software is copyright (c) 2016 by Chris Williams.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
